import { Button } from "@/components/ui/button";
import { Icon } from "@iconify/react/dist/iconify.js";
import { Loader2 } from "lucide-react";
import { useTranslations } from "next-intl";
import { useRouter } from "next/navigation";

interface AddToCartButtonProps {
	isPending: boolean;
	handleAddToCart: () => void;
}

const CartButtons = ({ isPending, handleAddToCart }: AddToCartButtonProps) => {
	const t = useTranslations("Common");
	const router = useRouter();

	return (
		<div className="flex flex-row gap-10">
			<Button
				size="default"
				className="w-[16rem] rounded-md bg-custom-primary-accent px-8 py-6 mt-12 text-white border border-custom-primary-accent hover:bg-white hover:text-[#2895C8]/90"
				onClick={handleAddToCart}
				disabled={isPending}
			>
				{isPending ? <Loader2 className="h-4 w-4 animate-spin" /> :
					<div className="flex flex-row items-center gap-2">
						<Icon icon="material-symbols:add-shopping-cart-rounded" style={{ width: "1.5rem", height: "1.5rem" }} />
						{t("AddToCart")}
					</div>
				}
			</Button>
			<Button
				size="default"
				className="w-[16rem] rounded-md border border-custom-primary-accent bg-white px-8 py-6 mt-12 text-custom-primary-accent hover:bg-[#2895C8]/90 hover:text-white"
				onClick={() => router.push("/cart")}
			>
				<Icon icon="mdi:cart" style={{ width: "1.5rem", height: "1.5rem" }} />
				{t("GoToCart")}
			</Button>
		</div>
	);
};

export default CartButtons; 